@@ -244,7 +244,7 @@ class JsonObject:
         return None
 
     def __dataframe_values__(self):
-        return [v.to_dataframe() if isinstance(v, JsonList,JsonObject) else v for v in self.get_values()]
+        return [v.to_dataframe() if isinstance(v, (JsonList, JsonObject)) else v for v in self.get_values()]
 
     def to_dataframe(self):
         from pandas import DataFrame
